@@ -803,11 +803,12 @@ def do_translate(config_flag=False):
     global YTDL_UPDATE_DICT
 
     global MAIN_STAGE_QUEUED, MAIN_STAGE_ACTIVE, MAIN_STAGE_PAUSED, \
-    MAIN_STAGE_COMPLETED, MAIN_STAGE_ERROR, ACTIVE_STAGE_PRE_PROCESS, \
-    ACTIVE_STAGE_DOWNLOAD, ACTIVE_STAGE_POST_PROCESS, ACTIVE_STAGE_CAPTURE, \
-    ACTIVE_STAGE_MERGE, ACTIVE_STAGE_CHECKING, COMPLETED_STAGE_FINISHED, \
-    COMPLETED_STAGE_WARNING, COMPLETED_STAGE_ALREADY, ERROR_STAGE_ERROR, \
-    ERROR_STAGE_STOPPED, ERROR_STAGE_ABORT
+    MAIN_STAGE_COMPLETED, MAIN_STAGE_ERROR, MAIN_STAGET_STALLED, \
+    ACTIVE_STAGE_PRE_PROCESS, ACTIVE_STAGE_DOWNLOAD, \
+    ACTIVE_STAGE_POST_PROCESS, ACTIVE_STAGE_CAPTURE, ACTIVE_STAGE_MERGE, \
+    ACTIVE_STAGE_CHECKING, COMPLETED_STAGE_FINISHED, COMPLETED_STAGE_WARNING, \
+    COMPLETED_STAGE_ALREADY, ERROR_STAGE_ERROR, ERROR_STAGE_STOPPED, \
+    ERROR_STAGE_ABORT
 
     global TIME_METRIC_TRANS_DICT
 
@@ -858,6 +859,7 @@ def do_translate(config_flag=False):
     MAIN_STAGE_PAUSED = _('Paused')                     # (not actually used)
     MAIN_STAGE_COMPLETED = _('Completed')               # (not actually used)
     MAIN_STAGE_ERROR = _('Error')
+    MAIN_STAGE_STALLED = _('Stalled')
     # Sub-stages of the 'Active' stage
     ACTIVE_STAGE_PRE_PROCESS = _('Pre-processing')
     ACTIVE_STAGE_DOWNLOAD = _('Downloading')
