@@ -39,10 +39,6 @@ import utils
 from mainapp import _
 
 
-# Debugging flag (calls utils.debug_time at the start of every function)
-DEBUG_FUNC_FLAG = False
-
-
 # Classes
 
 
@@ -69,9 +65,6 @@ class RefreshManager(threading.Thread):
 
     def __init__(self, app_obj, init_obj=None):
 
-        if DEBUG_FUNC_FLAG:
-            utils.debug_time('rop 73 __init__')
-
         super(RefreshManager, self).__init__()
 
         # IV list - class objects
@@ -139,9 +132,6 @@ class RefreshManager(threading.Thread):
         complete.
         """
 
-        if DEBUG_FUNC_FLAG:
-            utils.debug_time('rop 143 run')
-
         # Show information about the refresh operation in the Output Tab
         if not self.init_obj:
             self.app_obj.main_win_obj.output_tab_write_stdout(
@@ -248,9 +238,6 @@ class RefreshManager(threading.Thread):
 
         """
 
-        if DEBUG_FUNC_FLAG:
-            utils.debug_time('rop 252 refresh_from_default_destination')
-
         # Update the main window's progress bar
         self.job_count += 1
         GObject.timeout_add(
@@ -290,8 +277,8 @@ class RefreshManager(threading.Thread):
             # Can't read the directory
             return
 
-        # From this list, filter out files without a recognised file extension
-        #   (.mp4, .webm, etc)
+        # From this list, filter out files without a recognised video/audio
+        #   file extension (.mp4, .webm, etc)
         mod_list = []
         for relative_path in init_list:
 
@@ -303,7 +290,8 @@ class RefreshManager(threading.Thread):
             filename, ext = os.path.splitext(relative_path)
             # (Remove the initial .)
             ext = ext[1:]
-            if ext in formats.VIDEO_FORMAT_DICT:
+            if ext in formats.VIDEO_FORMAT_DICT \
+            or ext in formats.AUDIO_FORMAT_DICT:
 
                 mod_list.append(relative_path)
 
@@ -519,9 +507,6 @@ class RefreshManager(threading.Thread):
 
         """
 
-        if DEBUG_FUNC_FLAG:
-            utils.debug_time('rop 519 refresh_from_actual_destination')
-
         # Update the main window's progress bar
         self.job_count += 1
         GObject.timeout_add(
@@ -617,7 +602,4 @@ class RefreshManager(threading.Thread):
         Stops the refresh operation.
         """
 
-        if DEBUG_FUNC_FLAG:
-            utils.debug_time('rop 613 stop_refresh_operation')
-
         self.running_flag = False
